django-ftp-deploy
=================

.. image:: https://travis-ci.org/lpakula/django-ftp-deploy.svg?branch=master
    :target: https://travis-ci.org/lpakula/django-ftp-deploy

.. image:: https://pypip.in/download/django-ftp-deploy/badge.svg
    :target: https://pypi.python.org/pypi//django-ftp-deploy/
    :alt: Downloads

django-ftp-deploy allows you to automatically deploy GIT repositories to FTP servers. You don't need to install git on the server!


**Features:**

* Manage multiple services (a service is one repository-to-ftp configuration)
* Verification service configuration
* Repository hook management
* Restore failed deploys
* Email notifications
* Logs and Statistics


Supported GIT repositories:

* Bitbucket
* Github


Documentation
-------------

`Read The Docs <http://django-ftp-deploy.readthedocs.org/en/latest/>`_.
